<?php
include 'db.php';
session_start();

// Mostrar errores de PHP para depuración
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit;
}

// Manejo de búsqueda
$search_query = "";
if (isset($_GET['search'])) {
    $search_query = $_GET['search'];
}

// Verificar y actualizar el estado de las MACs basadas en la fecha de expiración
$now = new DateTime();
$expiration_check_sql = "UPDATE macs SET status = 'inactive' WHERE expiration_date IS NOT NULL AND expiration_date <= ? AND status = 'active'";
$expiration_stmt = $conn->prepare($expiration_check_sql);
$expiration_date = $now->format('Y-m-d H:i:s');
$expiration_stmt->bind_param('s', $expiration_date);
$expiration_stmt->execute();
$expiration_stmt->close();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['update_package'])) {
        $mac_id = $_POST['mac_id'];
        $package_id = $_POST['package_id'];

        // Obtener la URL del XML del paquete seleccionado
        $package_sql = "SELECT xml_url FROM packages WHERE id = ?";
        $package_stmt = $conn->prepare($package_sql);
        $package_stmt->bind_param("i", $package_id);
        $package_stmt->execute();
        $package_stmt->bind_result($xml_url);
        $package_stmt->fetch();
        $package_stmt->close();

        // Actualizar el package_id y la URL del XML en la tabla macs
        $update_sql = "UPDATE macs SET package_id = ?, xml_url = ? WHERE id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param('isi', $package_id, $xml_url, $mac_id);
        $update_stmt->execute();
        $update_stmt->close();

        echo "<script>
            document.addEventListener('DOMContentLoaded', function() {
                Swal.fire({
                    title: 'Actualización Exitosa',
                    text: 'Paquete actualizado correctamente.',
                    icon: 'success'
                }).then(() => {
                    window.location.href='manage_macs.php?search=" . urlencode($search_query) . "';
                });
            });
        </script>";
    }

    // Manejo de activación/desactivación de MAC
    if (isset($_POST['toggle_status'])) {
        $mac_id = $_POST['mac_id'];
        $current_status = $_POST['current_status'];

        if ($current_status === 'inactive') {
            $new_status = 'active';
            $new_expiration_date = $now->modify('+30 days')->format('Y-m-d H:i:s');

            $update_sql = "UPDATE macs SET status = ?, expiration_date = ? WHERE id = ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param('ssi', $new_status, $new_expiration_date, $mac_id);
        } else {
            $new_status = 'inactive';

            $update_sql = "UPDATE macs SET status = ? WHERE id = ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param('si', $new_status, $mac_id);
        }

        $update_stmt->execute();
        $update_stmt->close();

        echo "<script>
            document.addEventListener('DOMContentLoaded', function() {
                Swal.fire({
                    title: 'Actualización Exitosa',
                    text: 'Estado de la MAC actualizado a " . ($new_status === 'active' ? 'activo' : 'inactivo') . ".',
                    icon: 'success'
                }).then(() => {
                    window.location.href='manage_macs.php?search=" . urlencode($search_query) . "';
                });
            });
        </script>";
    }

    // Manejo de eliminación de MAC
    if (isset($_POST['delete_mac'])) {
        $mac_id = $_POST['mac_id'];

        echo "<script>
            document.addEventListener('DOMContentLoaded', function() {
                Swal.fire({
                    title: '¿Estás seguro?',
                    text: '¡No podrás revertir esto!',
                    icon: 'warning',
                    showCancelButton: true,
                    confirmButtonColor: '#3085d6',
                    cancelButtonColor: '#d33',
                    confirmButtonText: 'Sí, eliminar',
                    cancelButtonText: 'Cancelar'
                }).then((result) => {
                    if (result.isConfirmed) {
                        window.location.href = 'delete_mac.php?id=$mac_id&search=" . urlencode($search_query) . "';
                    }
                });
            });
        </script>";
    }

    // Manejo de actualización de fecha de expiración
    if (isset($_POST['update_expiration'])) {
        $mac_id = $_POST['mac_id'];
        $expiration_date = $_POST['expiration_date'];

        $update_sql = "UPDATE macs SET expiration_date = ? WHERE id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param('si', $expiration_date, $mac_id);
        $update_stmt->execute();
        $update_stmt->close();

        echo "<script>
            document.addEventListener('DOMContentLoaded', function() {
                Swal.fire({
                    title: 'Actualización Exitosa',
                    text: 'Fecha de expiración actualizada correctamente.',
                    icon: 'success'
                }).then(() => {
                    window.location.href='manage_macs.php?search=" . urlencode($search_query) . "';
                });
            });
        </script>";
    }
}

$user_id = $_SESSION['user_id'];
$sql = "
    SELECT m.id, m.mac_address, m.status, m.expiration_date, m.first_name, m.last_name, m.system_id, s.site_name, s.id AS site_id, m.package_id 
    FROM macs m 
    JOIN sites s ON m.site_id = s.id 
    WHERE m.user_id = ? AND 
        (m.first_name LIKE ? OR 
        m.last_name LIKE ? OR 
        m.system_id LIKE ? OR 
        s.site_name LIKE ?)
    ORDER BY m.id ASC";
$stmt = $conn->prepare($sql);

$search_term = '%' . $search_query . '%';
$stmt->bind_param('issss', $user_id, $search_term, $search_term, $search_term, $search_term);
$stmt->execute();

$result = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Gestionar MACs</title>
    <link href="vendor/fontawesome-free/css/all.min.css" rel="stylesheet" type="text/css">
    <link href="css/sb-admin-2.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.min.css" rel="stylesheet">
</head>
<body id="page-top">

<!-- Page Wrapper -->
<div id="wrapper">

    <!-- Sidebar -->
    <ul class="navbar-nav bg-gradient-primary sidebar sidebar-dark accordion" id="accordionSidebar">
        <!-- Sidebar code remains unchanged -->
        <a class="sidebar-brand d-flex align-items-center justify-content-center" href="index.php">
            <div class="sidebar-brand-icon">
                <i class="fas fa-user-shield"></i>
            </div>
            <div class="sidebar-brand-text mx-3">Mi Admin</div>
        </a>
        <hr class="sidebar-divider my-0">
        <li class="nav-item">
            <a class="nav-link" href="index.php">
                <i class="fas fa-fw fa-tachometer-alt"></i>
                <span>Dashboard</span></a>
        </li>
        <li class="nav-item">
            <a class="nav-link" href="manage_macs.php">
                <i class="fas fa-fw fa-table"></i>
                <span>Gestionar MACs</span></a>
        </li>
        <li class="nav-item">
            <a class="nav-link" href="register_mac.php">
                <i class="fas fa-fw fa-address-book"></i>
                <span>Registrar MAC</span></a>
        </li>
        <li class="nav-item">
            <a class="nav-link" href="register_site.php">
                <i class="fas fa-fw fa-folder"></i>
                <span>Registrar Sitios</span></a>
        </li>
        <hr class="sidebar-divider d-none d-md-block">
        <div class="text-center d-none d-md-inline">
            <button class="rounded-circle border-0" id="sidebarToggle"></button>
        </div>
    </ul>
    <!-- End of Sidebar -->

    <!-- Content Wrapper -->
    <div id="content-wrapper" class="d-flex flex-column">

        <!-- Main Content -->
        <div id="content">

            <!-- Topbar -->
            <nav class="navbar navbar-expand navbar-light bg-white topbar mb-4 static-top shadow">
                <button id="sidebarToggleTop" class="btn btn-link d-md-none rounded-circle mr-3">
                    <i class="fa fa-bars"></i>
                </button>
                <ul class="navbar-nav ml-auto">
                    <li class="nav-item dropdown no-arrow">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                            <span class="mr-2 d-none d-lg-inline text-gray-600 small"><?php echo $_SESSION['user_name']; ?></span>
                            <img class="img-profile rounded-circle" src="img/undraw_profile.svg">
                        </a>
                        <div class="dropdown-menu dropdown-menu-right shadow animated--grow-in" aria-labelledby="userDropdown">
                            <a class="dropdown-item" href="#">
                                <i class="fas fa-user fa-sm fa-fw mr-2 text-gray-400"></i>
                                Perfil
                            </a>
                            <div class="dropdown-divider"></div>
                            <a class="dropdown-item" href="logout.php">
                                <i class="fas fa-sign-out-alt fa-sm fa-fw mr-2 text-gray-400"></i>
                                Cerrar Sesión
                            </a>
                        </div>
                    </li>
                </ul>
            </nav>
            <!-- End of Topbar -->

            <!-- Begin Page Content -->
            <div class="container-fluid">
                <h2 class="h3 mb-4 text-gray-800">Gestionar MACs</h2>

                <!-- Formulario de búsqueda -->
                <form method="GET" action="manage_macs.php" class="form-inline mb-4">
                    <input type="text" name="search" class="form-control mr-2" placeholder="Buscar por nombre, código o sitio" value="<?php echo $search_query; ?>">
                    <input type="submit" value="Buscar" class="btn btn-primary">
                </form>

                <div class="card shadow mb-4">
                    <div class="card-header py-3">
                        <h6 class="m-0 font-weight-bold text-primary">Listado de MACs</h6>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-bordered" id="dataTable" width="100%" cellspacing="0">
                                <thead>
                                    <tr>
                                        <th>MAC</th>
                                        <th>Nombre</th>
                                        <th>Apellido</th>
                                        <th>Sitio</th>
                                        <th>Código del Sistema</th>
                                        <th>Estado</th>
                                        <th>Fecha de Expiración</th>
                                        <th>Paquete</th>
                                        <th>Acciones</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php while ($row = $result->fetch_assoc()) { ?>
                                    <tr>
                                        <td><?php echo $row['mac_address']; ?></td>
                                        <td><?php echo $row['first_name']; ?></td>
                                        <td><?php echo $row['last_name']; ?></td>
                                        <td><?php echo $row['site_name']; ?></td>
                                        <td><?php echo $row['system_id']; ?></td>
                                        <td><?php echo $row['status']; ?></td>
                                        <td>
                                            <form method="POST" action="manage_macs.php" style="display:inline;">
                                                <input type="hidden" name="mac_id" value="<?php echo $row['id']; ?>">
                                                <input type="datetime-local" name="expiration_date" value="<?php echo date('Y-m-d\TH:i', strtotime($row['expiration_date'])); ?>" class="form-control">
                                                <input type="submit" name="update_expiration" value="Actualizar Fecha" class="btn btn-secondary btn-sm mt-2">
                                            </form>
                                        </td>
                                        <td>
                                            <form method="POST" action="manage_macs.php" style="display:inline;">
                                                <select name="package_id" class="form-control">
                                                    <?php
                                                    $package_sql = "SELECT id, package_name FROM packages WHERE site_id = ?";
                                                    $package_stmt = $conn->prepare($package_sql);
                                                    $package_stmt->bind_param("i", $row['site_id']);
                                                    $package_stmt->execute();
                                                    $package_result = $package_stmt->get_result();

                                                    if ($package_result->num_rows > 0) {
                                                        while ($package = $package_result->fetch_assoc()) {
                                                            $selected = ($package['id'] == $row['package_id']) ? "selected" : "";
                                                            echo "<option value='{$package['id']}' $selected>{$package['package_name']}</option>";
                                                        }
                                                    } else {
                                                        echo "<option value=''>No hay paquetes disponibles</option>";
                                                    }
                                                    
                                                    $package_stmt->close();
                                                    ?>
                                                </select>
                                                <input type="hidden" name="mac_id" value="<?php echo $row['id']; ?>">
                                                <input type="submit" name="update_package" value="Asignar Paquete" class="btn btn-info btn-sm mt-2">
                                            </form>
                                        </td>
                                        <td>
                                            <form method="POST" action="manage_macs.php" style="display:inline;">
                                                <input type="hidden" name="mac_id" value="<?php echo $row['id']; ?>">
                                                <input type="hidden" name="current_status" value="<?php echo $row['status']; ?>">
                                                <input type="submit" name="toggle_status" value="<?php echo $row['status'] === 'active' ? 'Desactivar' : 'Activar'; ?>" class="btn <?php echo $row['status'] === 'active' ? 'btn-danger' : 'btn-success'; ?> btn-sm">
                                            </form>
                                            <form method="POST" action="manage_macs.php" style="display:inline;">
                                                <input type="hidden" name="mac_id" value="<?php echo $row['id']; ?>">
                                                <input type="submit" name="delete_mac" value="Eliminar" class="btn btn-danger btn-sm">
                                            </form>
                                        </td>
                                    </tr>
                                    <?php } ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>

                <br>
                <form action="index.php" method="get">
                    <input type="submit" value="Regresar al Panel Principal" class="btn btn-primary">
                </form>
            </div>
            <!-- /.container-fluid -->

        </div>
        <!-- End of Main Content -->

        <!-- Footer -->
        <footer class="sticky-footer bg-white">
            <div class="container my-auto">
                <div class="copyright text-center my-auto">
                    <span>Copyright &copy; SISTEMAS TECNICOS E INGENIERIA 2024</span>
                </div>
            </div>
        </footer>
        <!-- End of Footer -->

    </div>
    <!-- End of Content Wrapper -->

</div>
<!-- End of Page Wrapper -->

<!-- JavaScript -->
<script src="vendor/jquery/jquery.min.js"></script>
<script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>
<script src="vendor/jquery-easing/jquery.easing.min.js"></script>
<script src="js/sb-admin-2.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

</body>
</html>

<?php
$stmt->close();
$conn->close();
?>