<?php
include 'db.php';
session_start();

if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: login.php");
    exit;
}

// Manejar la búsqueda
$search_query = "";
if (isset($_GET['search'])) {
    $search_query = $_GET['search'];
}

// Procesar formulario de edición de usuario
if (isset($_POST['save_changes'])) {
    $edit_user_id = $_POST['edit_user_id'];
    $username = $_POST['username'];
    $company_name = $_POST['company_name'];
    $country = $_POST['country'];
    $email = $_POST['email'];
    $contact_number = $_POST['contact_number'];
    $mac_limit = $_POST['mac_limit'];
    $status = $_POST['status'];
    $password = $_POST['password'];

    if (!empty($password)) {
        // Actualizar usuario con contraseña
        $hashed_password = password_hash($password, PASSWORD_DEFAULT);
        $update_sql = "UPDATE users SET username = ?, company_name = ?, country = ?, email = ?, contact_number = ?, mac_limit = ?, status = ?, password = ? WHERE id = ?";
        $stmt = $conn->prepare($update_sql);
        $stmt->bind_param("ssssssisi", $username, $company_name, $country, $email, $contact_number, $mac_limit, $status, $hashed_password, $edit_user_id);
    } else {
        // Actualizar usuario sin cambiar contraseña
        $update_sql = "UPDATE users SET username = ?, company_name = ?, country = ?, email = ?, contact_number = ?, mac_limit = ?, status = ? WHERE id = ?";
        $stmt = $conn->prepare($update_sql);
        $stmt->bind_param("sssssssi", $username, $company_name, $country, $email, $contact_number, $mac_limit, $status, $edit_user_id);
    }

    if ($stmt->execute()) {
        $_SESSION['success_message'] = 'Cambios guardados exitosamente.';
    } else {
        $_SESSION['error_message'] = 'Error al guardar los cambios: ' . $stmt->error;
    }

    $stmt->close();

    // Redireccionar para evitar el reenvío de formularios al recargar la página
    header("Location: manage_users.php");
    exit;
}

// Procesar eliminación de usuario
if (isset($_POST['delete_user']) && isset($_POST['delete_user_id'])) {
    $delete_user_id = $_POST['delete_user_id'];

    $conn->begin_transaction();

    try {
        // Eliminar las MACs asociadas
        $delete_macs_sql = "DELETE FROM macs WHERE user_id = ?";
        $stmt = $conn->prepare($delete_macs_sql);
        if (!$stmt) {
            throw new Exception("Error en preparar la consulta DELETE macs: " . $conn->error);
        }
        $stmt->bind_param("i", $delete_user_id);
        if (!$stmt->execute()) {
            throw new Exception("Error al ejecutar la consulta DELETE macs: " . $stmt->error);
        }
        $stmt->close();

        // Eliminar los sitios asociados
        $delete_sites_sql = "DELETE FROM sites WHERE user_id = ?";
        $stmt = $conn->prepare($delete_sites_sql);
        if (!$stmt) {
            throw new Exception("Error en preparar la consulta DELETE sites: " . $conn->error);
        }
        $stmt->bind_param("i", $delete_user_id);
        if (!$stmt->execute()) {
            throw new Exception("Error al ejecutar la consulta DELETE sites: " . $stmt->error);
        }
        $stmt->close();

        // Eliminar los paquetes asociados
        $delete_packages_sql = "DELETE FROM packages WHERE user_id = ?";
        $stmt = $conn->prepare($delete_packages_sql);
        if (!$stmt) {
            throw new Exception("Error en preparar la consulta DELETE packages: " . $conn->error);
        }
        $stmt->bind_param("i", $delete_user_id);
        if (!$stmt->execute()) {
            throw new Exception("Error al ejecutar la consulta DELETE packages: " . $stmt->error);
        }
        $stmt->close();

        // Eliminar el usuario
        $delete_user_sql = "DELETE FROM users WHERE id = ?";
        $stmt = $conn->prepare($delete_user_sql);
        if (!$stmt) {
            throw new Exception("Error en preparar la consulta DELETE users: " . $conn->error);
        }
        $stmt->bind_param("i", $delete_user_id);
        if (!$stmt->execute()) {
            throw new Exception("Error al ejecutar la consulta DELETE users: " . $stmt->error);
        }
        $stmt->close();

        $conn->commit();
        $_SESSION['success_message'] = 'Usuario y todos los registros asociados han sido eliminados.';
    } catch (Exception $e) {
        $conn->rollback();
        $_SESSION['error_message'] = 'Error al eliminar el usuario y sus registros asociados: ' . $e->getMessage();
    }

    // Redireccionar para evitar el reenvío de formularios al recargar la página
    header("Location: manage_users.php");
    exit;
}

// Consultar usuarios
$sql = "SELECT * FROM users WHERE username LIKE ?";
$stmt = $conn->prepare($sql);
$search_term = '%' . $search_query . '%';
$stmt->bind_param('s', $search_term);
$stmt->execute();
$result = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestionar Usuarios</title>
    <link href="vendor/fontawesome-free/css/all.min.css" rel="stylesheet" type="text/css">
    <link href="https://fonts.googleapis.com/css?family=Nunito:200,300,400,600,700,800,900" rel="stylesheet">
    <link href="css/sb-admin-2.min.css" rel="stylesheet">
    <script src="vendor/jquery/jquery.min.js"></script>
    <script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
</head>
<body id="page-top">

    <!-- Page Wrapper -->
    <div id="wrapper">

        <!-- Sidebar -->
        <ul class="navbar-nav bg-gradient-primary sidebar sidebar-dark accordion" id="accordionSidebar">
            <!-- Sidebar - Brand -->
            <a class="sidebar-brand d-flex align-items-center justify-content-center" href="admin_dashboard.php">
                <div class="sidebar-brand-icon">
                    <i class="fas fa-user-shield"></i>
                </div>
                <div class="sidebar-brand-text mx-3">Mi Admin</div>
            </a>

            <!-- Divider -->
            <hr class="sidebar-divider my-0">

            <!-- Nav Item - Dashboard -->
            <li class="nav-item">
                <a class="nav-link" href="admin_dashboard.php">
                    <i class="fas fa-fw fa-tachometer-alt"></i>
                    <span>Dashboard</span></a>
            </li>

            <!-- Divider -->
            <hr class="sidebar-divider">

            <!-- Heading -->
            <div class="sidebar-heading">
                Gestión
            </div>

            <!-- Nav Item - Manage Users -->
            <li class="nav-item">
                <a class="nav-link" href="manage_users.php">
                    <i class="fas fa-fw fa-users"></i>
                    <span>Gestionar Usuarios</span></a>
            </li>

            <!-- Nav Item - Manage MACs -->
            <li class="nav-item">
                <a class="nav-link" href="manage_macs.php">
                    <i class="fas fa-fw fa-table"></i>
                    <span>Gestionar MACs</span></a>
            </li>

            <!-- Nav Item - Register Site -->
            <li class="nav-item">
                <a class="nav-link" href="register_site.php">
                    <i class="fas fa-fw fa-folder"></i>
                    <span>Registrar Sitios</span></a>
            </li>

            <!-- Nav Item - Register MAC -->
            <li class="nav-item">
                <a class="nav-link" href="register_mac.php">
                    <i class="fas fa-fw fa-address-book"></i>
                    <span>Registrar MAC</span></a>
            </li>

            <!-- Divider -->
            <hr class="sidebar-divider d-none d-md-block">

            <!-- Sidebar Toggler (Sidebar) -->
            <div class="text-center d-none d-md-inline">
                <button class="rounded-circle border-0" id="sidebarToggle"></button>
            </div>

        </ul>
        <!-- End of Sidebar -->

        <!-- Content Wrapper -->
        <div id="content-wrapper" class="d-flex flex-column">

            <!-- Main Content -->
            <div id="content">

                <!-- Topbar -->
                <nav class="navbar navbar-expand navbar-light bg-white topbar mb-4 static-top shadow">

                    <!-- Sidebar Toggle (Topbar) -->
                    <button id="sidebarToggleTop" class="btn btn-link d-md-none rounded-circle mr-3">
                        <i class="fa fa-bars"></i>
                    </button>

                    <!-- Topbar Navbar -->
                    <ul class="navbar-nav ml-auto">
                        <li class="nav-item dropdown no-arrow">
                            <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                <span class="mr-2 d-none d-lg-inline text-gray-600 small"><?php echo $_SESSION['user_name']; ?></span>
                                <img class="img-profile rounded-circle" src="img/undraw_profile.svg">
                            </a>
                            <div class="dropdown-menu dropdown-menu-right shadow animated--grow-in" aria-labelledby="userDropdown">
                                <a class="dropdown-item" href="#">
                                    <i class="fas fa-user fa-sm fa-fw mr-2 text-gray-400"></i>
                                    Perfil
                                </a>
                                <div class="dropdown-divider"></div>
                                <a class="dropdown-item" href="logout.php">
                                    <i class="fas fa-sign-out-alt fa-sm fa-fw mr-2 text-gray-400"></i>
                                    Cerrar Sesión
                                </a>
                            </div>
                        </li>
                    </ul>
                </nav>
                <!-- End of Topbar -->

                <!-- Begin Page Content -->
                <div class="container-fluid">

                    <h2>Gestionar Usuarios</h2>

                    <!-- Formulario de búsqueda -->
                    <form method="GET" action="manage_users.php" class="form-inline mb-3">
                        <div class="input-group">
                            <input type="text" name="search" placeholder="Buscar usuario..." class="form-control" value="<?php echo htmlspecialchars($search_query); ?>">
                            <div class="input-group-append">
                                <button type="submit" class="btn btn-primary">Buscar</button>
                            </div>
                        </div>
                    </form>

                    <!-- Tabla de usuarios -->
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Nombre de Usuario</th>
                                <th>Nombre de la Empresa</th>
                                <th>País</th>
                                <th>Correo Electrónico</th>
                                <th>Número de Contacto</th>
                                <th>Límite de MACs</th>
                                <th>Estado</th>
                                <th>Acciones</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php while ($row = $result->fetch_assoc()) { ?>
                                <tr>
                                    <td><?php echo $row['id']; ?></td>
                                    <td><?php echo $row['username']; ?></td>
                                    <td><?php echo $row['company_name']; ?></td>
                                    <td><?php echo $row['country']; ?></td>
                                    <td><?php echo $row['email']; ?></td>
                                    <td><?php echo $row['contact_number']; ?></td>
                                    <td><?php echo $row['mac_limit']; ?></td>
                                    <td><?php echo $row['status'] ? 'Activo' : 'Inactivo'; ?></td>
                                    <td>
                                        <button class="btn btn-primary btn-sm editBtn" 
                                                data-id="<?php echo $row['id']; ?>"
                                                data-username="<?php echo $row['username']; ?>"
                                                data-company="<?php echo $row['company_name']; ?>"
                                                data-country="<?php echo $row['country']; ?>"
                                                data-email="<?php echo $row['email']; ?>"
                                                data-contact="<?php echo $row['contact_number']; ?>"
                                                data-limit="<?php echo $row['mac_limit']; ?>"
                                                data-status="<?php echo $row['status']; ?>"
                                                data-toggle="modal" data-target="#editUserModal">
                                            Editar
                                        </button>
                                        <button class="btn btn-danger btn-sm deleteBtn" data-id="<?php echo $row['id']; ?>">Eliminar</button>
                                    </td>
                                </tr>
                            <?php } ?>
                        </tbody>
                    </table>

                    <!-- Modal para editar usuario -->
                    <div class="modal fade" id="editUserModal" tabindex="-1" role="dialog" aria-labelledby="editUserModalLabel" aria-hidden="true">
                        <div class="modal-dialog" role="document">
                            <div class="modal-content">
                                <form method="POST" action="manage_users.php">
                                    <div class="modal-header">
                                        <h5 class="modal-title" id="editUserModalLabel">Editar Usuario</h5>
                                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                            <span aria-hidden="true">&times;</span>
                                        </button>
                                    </div>
                                    <div class="modal-body">
                                        <input type="hidden" name="edit_user_id" id="edit_user_id">
                                        <!-- Otros campos para editar el usuario -->
                                        <div class="form-group">
                                            <label for="username">Nombre de Usuario</label>
                                            <input type="text" class="form-control" id="edit_username" name="username">
                                        </div>
                                        <div class="form-group">
                                            <label for="company_name">Nombre de la Empresa</label>
                                            <input type="text" class="form-control" id="edit_company_name" name="company_name">
                                        </div>
                                        <div class="form-group">
                                            <label for="country">País</label>
                                            <input type="text" class="form-control" id="edit_country" name="country">
                                        </div>
                                        <div class="form-group">
                                            <label for="email">Correo Electrónico</label>
                                            <input type="email" class="form-control" id="edit_email" name="email">
                                        </div>
                                        <div class="form-group">
                                            <label for="contact_number">Número de Contacto</label>
                                            <input type="text" class="form-control" id="edit_contact_number" name="contact_number">
                                        </div>
                                        <div class="form-group">
                                            <label for="mac_limit">Límite de MACs</label>
                                            <input type="number" class="form-control" id="edit_mac_limit" name="mac_limit">
                                        </div>
                                        <div class="form-group">
                                            <label for="status">Estado</label>
                                            <select class="form-control" id="edit_status" name="status">
                                                <option value="1">Activo</option>
                                                <option value="0">Inactivo</option>
                                            </select>
                                        </div>
                                        <div class="form-group">
                                            <label for="password">Cambiar Contraseña</label>
                                            <input type="password" class="form-control" id="password" name="password" autocomplete="new-password">
                                        </div>
                                    </div>
                                    <div class="modal-footer">
                                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancelar</button>
                                        <button type="submit" name="save_changes" class="btn btn-primary">Guardar Cambios</button>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>

                </div>
                <!-- /.container-fluid -->

            </div>
            <!-- End of Main Content -->

            <!-- Footer -->
            <footer class="sticky-footer bg-white">
                <div class="container my-auto">
                    <div class="copyright text-center my-auto">
                        <span>Copyright &copy; SISTEMAS TECNICOS E INGENIERIA 2024</span>
                    </div>
                </div>
            </footer>
            <!-- End of Footer -->

        </div>
        <!-- End of Content Wrapper -->

    </div>
    <!-- End of Page Wrapper -->

    <!-- Core plugin JavaScript-->
    <script src="vendor/jquery-easing/jquery.easing.min.js"></script>
    <!-- Custom scripts for all pages-->
    <script src="js/sb-admin-2.min.js"></script>

    <script>
        $(document).ready(function() {
            // Mostrar mensaje de éxito o error
            <?php if (isset($_SESSION['success_message'])) { ?>
                Swal.fire('Éxito', '<?php echo $_SESSION['success_message']; ?>', 'success');
                <?php unset($_SESSION['success_message']); ?>
            <?php } elseif (isset($_SESSION['error_message'])) { ?>
                Swal.fire('Error', '<?php echo $_SESSION['error_message']; ?>', 'error');
                <?php unset($_SESSION['error_message']); ?>
            <?php } ?>

            $('.editBtn').on('click', function() {
                var userId = $(this).data('id');
                var username = $(this).data('username');
                var companyName = $(this).data('company');
                var country = $(this).data('country');
                var email = $(this).data('email');
                var contactNumber = $(this).data('contact');
                var macLimit = $(this).data('limit');
                var status = $(this).data('status');

                $('#edit_user_id').val(userId);
                $('#edit_username').val(username);
                $('#edit_company_name').val(companyName);
                $('#edit_country').val(country);
                $('#edit_email').val(email);
                $('#edit_contact_number').val(contactNumber);
                $('#edit_mac_limit').val(macLimit);
                $('#edit_status').val(status);
            });

            $('.deleteBtn').on('click', function() {
                var userId = $(this).data('id');
                Swal.fire({
                    title: '¿Estás seguro?',
                    text: "¡No podrás revertir esto!",
                    icon: 'warning',
                    showCancelButton: true,
                    confirmButtonColor: '#3085d6',
                    cancelButtonColor: '#d33',
                    confirmButtonText: 'Sí, eliminarlo!'
                }).then((result) => {
                    if (result.isConfirmed) {
                        $.post('manage_users.php', { delete_user: true, delete_user_id: userId }, function(response) {
                            Swal.fire(
                                '¡Eliminado!',
                                'El usuario ha sido eliminado.',
                                'success'
                            ).then(() => {
                                window.location.reload();
                            });
                        }).fail(function() {
                            Swal.fire('Error', 'No se pudo eliminar el usuario.', 'error');
                        });
                    }
                });
            });
        });
    </script>

</body>
</html>

<?php
$conn->close();
?>