<?php
include 'db.php';
session_start();

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit;
}

$user_id = $_SESSION['user_id'];

// Verificar si el usuario ha alcanzado el límite de MACs permitidas
$mac_count_sql = "SELECT COUNT(*) as mac_count FROM macs WHERE user_id = ?";
$stmt = $conn->prepare($mac_count_sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();
$mac_count = $result->fetch_assoc()['mac_count'];

$user_sql = "SELECT mac_limit FROM users WHERE id = ?";
$stmt = $conn->prepare($user_sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();
$mac_limit = $user['mac_limit'];

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if ($mac_count < $mac_limit) {
        $mac_address = $_POST['mac_address'];
        $site_id = $_POST['site_id'];
        $first_name = $_POST['first_name'];
        $last_name = $_POST['last_name'];
        $system_id = $_POST['system_id'];
        $address = $_POST['address'];
        $phone_number = $_POST['phone_number'];
        $email = $_POST['email'];

        $sql = "INSERT INTO macs (mac_address, site_id, first_name, last_name, system_id, address, phone_number, email, user_id) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("sissssssi", $mac_address, $site_id, $first_name, $last_name, $system_id, $address, $phone_number, $email, $user_id);

        if ($stmt->execute()) {
            echo "<script>
                document.addEventListener('DOMContentLoaded', function() {
                    Swal.fire({
                        title: 'Éxito',
                        text: 'MAC registrada exitosamente.',
                        icon: 'success',
                        confirmButtonText: 'Aceptar'
                    }).then(() => {
                        window.location.href = 'register_mac.php';
                    });
                });
            </script>";
        } else {
            echo "<script>
                document.addEventListener('DOMContentLoaded', function() {
                    Swal.fire({
                        title: 'Error',
                        text: 'Error MAC ya fue asignada.',
                        icon: 'error',
                        confirmButtonText: 'Aceptar'
                    });
                });
            </script>";
        }
        $stmt->close();
    } else {
        echo "<script>
            document.addEventListener('DOMContentLoaded', function() {
                Swal.fire({
                    title: 'Límite alcanzado',
                    text: 'Ha alcanzado el límite de MACs permitidas.',
                    icon: 'warning',
                    confirmButtonText: 'Aceptar'
                });
            });
        </script>";
    }
}

// Obtener los sitios registrados por el usuario
$sites_sql = "SELECT id, site_name FROM sites WHERE user_id = ?";
$stmt = $conn->prepare($sites_sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$sites_result = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registrar MAC</title>
    <link href="vendor/fontawesome-free/css/all.min.css" rel="stylesheet" type="text/css">
    <link href="css/sb-admin-2.min.css" rel="stylesheet">
    <script src="vendor/jquery/jquery.min.js"></script>
    <script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
</head>
<body id="page-top">

<!-- Page Wrapper -->
<div id="wrapper">

    <!-- Sidebar -->
    <ul class="navbar-nav bg-gradient-primary sidebar sidebar-dark accordion" id="accordionSidebar">
        <!-- Sidebar code remains unchanged -->
        <a class="sidebar-brand d-flex align-items-center justify-content-center" href="index.php">
            <div class="sidebar-brand-icon">
                <i class="fas fa-user-shield"></i>
            </div>
            <div class="sidebar-brand-text mx-3">Mi Admin</div>
        </a>
        <hr class="sidebar-divider my-0">
        <li class="nav-item">
            <a class="nav-link" href="index.php">
                <i class="fas fa-fw fa-tachometer-alt"></i>
                <span>Dashboard</span></a>
        </li>
        <li class="nav-item">
            <a class="nav-link" href="manage_macs.php">
                <i class="fas fa-fw fa-table"></i>
                <span>Gestionar MACs</span></a>
        </li>
        <li class="nav-item">
            <a class="nav-link" href="register_mac.php">
                <i class="fas fa-fw fa-address-book"></i>
                <span>Registrar MAC</span></a>
        </li>
        <li class="nav-item">
            <a class="nav-link" href="register_site.php">
                <i class="fas fa-fw fa-folder"></i>
                <span>Registrar Sitios</span></a>
        </li>
        <hr class="sidebar-divider d-none d-md-block">
        <div class="text-center d-none d-md-inline">
            <button class="rounded-circle border-0" id="sidebarToggle"></button>
        </div>
    </ul>
    <!-- End of Sidebar -->

    <!-- Content Wrapper -->
    <div id="content-wrapper" class="d-flex flex-column">

        <!-- Main Content -->
        <div id="content">

            <!-- Topbar -->
            <nav class="navbar navbar-expand navbar-light bg-white topbar mb-4 static-top shadow">
                <button id="sidebarToggleTop" class="btn btn-link d-md-none rounded-circle mr-3">
                    <i class="fa fa-bars"></i>
                </button>
                <ul class="navbar-nav ml-auto">
                    <li class="nav-item dropdown no-arrow">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                            <span class="mr-2 d-none d-lg-inline text-gray-600 small"><?php echo $_SESSION['user_name']; ?></span>
                            <img class="img-profile rounded-circle" src="img/undraw_profile.svg">
                        </a>
                        <div class="dropdown-menu dropdown-menu-right shadow animated--grow-in" aria-labelledby="userDropdown">
                            <a class="dropdown-item" href="#">
                                <i class="fas fa-user fa-sm fa-fw mr-2 text-gray-400"></i>
                                Perfil
                            </a>
                            <div class="dropdown-divider"></div>
                            <a class="dropdown-item" href="logout.php">
                                <i class="fas fa-sign-out-alt fa-sm fa-fw mr-2 text-gray-400"></i>
                                Cerrar Sesión
                            </a>
                        </div>
                    </li>
                </ul>
            </nav>
            <!-- End of Topbar -->

            <!-- Begin Page Content -->
            <div class="container-fluid">

                <h2 class="h3 mb-4 text-gray-800">Registrar Nueva MAC</h2>
                <form method="POST" action="register_mac.php">
                    <div class="form-group">
                        <input type="text" class="form-control form-control-user" name="mac_address" placeholder="Dirección MAC" required>
                    </div>

                    <div class="form-group">
                        <select class="form-control" name="site_id" required>
                            <option value="">Selecciona el Sitio</option>
                            <?php while ($row = $sites_result->fetch_assoc()) { ?>
                                <option value="<?php echo $row['id']; ?>"><?php echo $row['site_name']; ?></option>
                            <?php } ?>
                        </select>
                    </div>

                    <!-- Other form fields -->
                    <div class="form-group">
                        <input type="text" class="form-control form-control-user" name="first_name" placeholder="Nombre" required>
                    </div>
                    <div class="form-group">
                        <input type="text" class="form-control form-control-user" name="last_name" placeholder="Apellido" required>
                    </div>
                    <div class="form-group">
                        <input type="text" class="form-control form-control-user" name="system_id" placeholder="Código de Identificación del Sistema" required>
                    </div>
                    <div class="form-group">
                        <input type="text" class="form-control form-control-user" name="address" placeholder="Dirección">
                    </div>
                    <div class="form-group">
                        <input type="text" class="form-control form-control-user" name="phone_number" placeholder="Número de Teléfono">
                    </div>
                    <div class="form-group">
                        <input type="email" class="form-control form-control-user" name="email" placeholder="Correo Electrónico">
                    </div>
                    <input type="submit" class="btn btn-primary btn-user btn-block" value="Registrar MAC">
                </form>
                <hr>
                <div class="text-center">
                    <a class="small" href="index.php">Regresar al Panel Principal</a>
                </div>

            </div>
            <!-- /.container-fluid -->

        </div>
        <!-- End of Main Content -->

        <!-- Footer -->
        <footer class="sticky-footer bg-white">
            <div class="container my-auto">
                <div class="copyright text-center my-auto">
                    <span>Copyright &copy; SISTEMAS TECNICOS E INGENIERIA 2024</span>
                </div>
            </div>
        </footer>
        <!-- End of Footer -->

    </div>
    <!-- End of Content Wrapper -->

</div>
<!-- End of Page Wrapper -->

<script src="vendor/jquery-easing/jquery.easing.min.js"></script>
<script src="js/sb-admin-2.min.js"></script>

</body>
</html>

<?php
$conn->close();
?>