<?php
include 'db.php';

// Iniciar sesión
session_start();

// Verificar si la sesión tiene un user_id
if (!isset($_SESSION['user_id'])) {
    die("Error: No se ha encontrado el ID del usuario en la sesión.");
}

// Obtener el user_id de la sesión
$user_id = $_SESSION['user_id'];

// Manejar la inserción de nuevos sitios
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_site'])) {
    if (!empty($_POST['new_site_name'])) {
        $site_name = $_POST['new_site_name'];

        // Insertar el sitio en la base de datos
        $sql = "INSERT INTO sites (site_name, user_id) VALUES (?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("si", $site_name, $user_id);
        $stmt->execute();
        
        // Obtener el ID del sitio recién creado
        $site_id = $stmt->insert_id;

        // Crear la carpeta en el servidor en la ruta especificada
        $directory_path = '/home/tuiphxvb/public_html/sitios/' . $site_name; // Reemplaza 'usuario' con tu usuario de hosting
        if (!file_exists($directory_path)) {
            if (mkdir($directory_path, 0777, true)) {
                echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Éxito', 'Carpeta creada exitosamente.', 'success'); });</script>";
            } else {
                echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Error', 'No se pudo crear la carpeta para el sitio.', 'error'); });</script>";
            }
        } else {
            echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Información', 'La carpeta ya existe.', 'info'); });</script>";
        }

        $stmt->close();
    }
}

// Manejar la inserción de nuevos paquetes
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_package'])) {
    if (!empty($_POST['site_id']) && !empty($_POST['new_package_name']) && isset($_FILES['m3u8_file'])) {
        $site_id = $_POST['site_id'];
        $package_name = $_POST['new_package_name'];

        // Manejar la subida del archivo M3U o M3U8
        $m3u8_file = $_FILES['m3u8_file'];
        $m3u8_file_tmp_path = $m3u8_file['tmp_name'];
        $m3u8_file_name = basename($m3u8_file['name']);

        // Verificar que el archivo es un .m3u o .m3u8
        $file_extension = pathinfo($m3u8_file_name, PATHINFO_EXTENSION);
        if ($file_extension === 'm3u' || $file_extension === 'm3u8') {

            // Ruta de la carpeta del sitio
            $site_folder_query = "SELECT site_name FROM sites WHERE id = ?";
            $site_folder_stmt = $conn->prepare($site_folder_query);
            $site_folder_stmt->bind_param("i", $site_id);
            $site_folder_stmt->execute();
            $site_folder_stmt->bind_result($site_name);
            $site_folder_stmt->fetch();
            $site_folder_stmt->close();

            $site_directory = '/home/tuiphxvb/public_html/sitios/' . $site_name; // Reemplaza 'usuario' con tu usuario de hosting

            // Verificar que la carpeta del sitio existe
            if (is_dir($site_directory)) {
                // Usar el nombre del paquete para el archivo XML resultante
                $xml_file_name = preg_replace('/[^A-Za-z0-9_\-]/', '_', $package_name) . '.xml'; // Reemplaza caracteres no permitidos
                $xml_file_path = $site_directory . '/' . $xml_file_name;

                // Convertir el archivo M3U/M3U8 a XML
                $xmlContent = '<?xml version="1.0" ?>' . PHP_EOL;
                $xmlContent .= '<list>' . PHP_EOL;

                $channelName = null;
                $handle = fopen($m3u8_file_tmp_path, "r");
                if ($handle) {
                    while (($line = fgets($handle)) !== false) {
                        $line = trim($line);
                        if (strpos($line, "#EXTINF:") === 0) {
                            $parts = explode(",", $line, 2);
                            $channelName = trim($parts[1]);
                        } elseif (!empty($line) && strpos($line, "#") !== 0) {
                            if ($channelName === null) {
                                $channelName = "UNKNOWN_CHANNEL";
                            }
                            $xmlContent .= '  <item>' . PHP_EOL;
                            $xmlContent .= '    <key>' . htmlspecialchars($channelName, ENT_QUOTES, 'UTF-8') . '</key>' . PHP_EOL;
                            $xmlContent .= '    <value>' . htmlspecialchars($line, ENT_QUOTES, 'UTF-8') . '</value>' . PHP_EOL;
                            $xmlContent .= '    <type>TV EN VIVO</type>' . PHP_EOL;
                            $xmlContent .= '  </item>' . PHP_EOL;
                            $channelName = null;
                        }
                    }
                    fclose($handle);
                }

                $xmlContent .= '</list>' . PHP_EOL;

                // Guardar el archivo XML en la carpeta del sitio
                if (file_put_contents($xml_file_path, $xmlContent) !== false) {
                    // Verificar si el archivo XML se creó correctamente
                    if (file_exists($xml_file_path)) {
                        // URL relativa del archivo XML para almacenar en la base de datos
                        $xml_url = 'https://tuiptvapp.com/sitios/' . $site_name . '/' . $xml_file_name;

                        // Incluir el user_id en la inserción del paquete con la URL del XML
                        $sql = "INSERT INTO packages (package_name, xml_url, site_id, user_id) VALUES (?, ?, ?, ?)";
                        $stmt = $conn->prepare($sql);
                        $stmt->bind_param("ssii", $package_name, $xml_url, $site_id, $user_id);
                        $stmt->execute();
                        $stmt->close();
                        
                        echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Éxito', 'Paquete guardado y archivo XML creado exitosamente.', 'success'); });</script>";
                    } else {
                        echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Error', 'No se pudo crear el archivo XML.', 'error'); });</script>";
                    }
                } else {
                    echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Error', 'No se pudo guardar el archivo XML.', 'error'); });</script>";
                }
            } else {
                echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Error', 'La carpeta del sitio no existe.', 'error'); });</script>";
            }
        } else {
            echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Error', 'Solo se permiten archivos .m3u o .m3u8.', 'error'); });</script>";
        }
    }
}

// Manejar la eliminación de sitios
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['delete_site_id'])) {
    $delete_site_id = $_POST['delete_site_id'];
    $sql = "DELETE FROM sites WHERE id = ? AND user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ii", $delete_site_id, $user_id);
    $stmt->execute();
    $stmt->close();
    echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Éxito', 'Sitio eliminado correctamente.', 'success'); });</script>";
}

// Manejar la eliminación de paquetes
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['delete_package_id'])) {
    $delete_package_id = $_POST['delete_package_id'];
    $sql = "DELETE FROM packages WHERE id = ? AND user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ii", $delete_package_id, $user_id);
    $stmt->execute();
    $stmt->close();
    echo "<script>document.addEventListener('DOMContentLoaded', function() { Swal.fire('Éxito', 'Paquete eliminado correctamente.', 'success'); });</script>";
}

// Obtener la lista de sitios registrados
$sites_sql = "SELECT id, site_name FROM sites WHERE user_id = ?";
$stmt = $conn->prepare($sites_sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$sites_result = $stmt->get_result();

// Obtener la lista de paquetes registrados para cada sitio
$packages_sql = "SELECT id, package_name, xml_url, site_id FROM packages WHERE user_id = ?";
$stmt_packages = $conn->prepare($packages_sql);
$stmt_packages->bind_param("i", $user_id);
$stmt_packages->execute();
$packages_result = $stmt_packages->get_result();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registrar Sitio y Paquetes</title>
    <link href="vendor/fontawesome-free/css/all.min.css" rel="stylesheet" type="text/css">
    <link href="css/sb-admin-2.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.min.css" rel="stylesheet">
</head>
<body id="page-top">
    <!-- Page Wrapper -->
    <div id="wrapper">

        <!-- Sidebar -->
        <ul class="navbar-nav bg-gradient-primary sidebar sidebar-dark accordion" id="accordionSidebar">
            <!-- Sidebar code remains unchanged -->
            <a class="sidebar-brand d-flex align-items-center justify-content-center" href="index.php">
                <div class="sidebar-brand-icon">
                    <i class="fas fa-user-shield"></i>
                </div>
                <div class="sidebar-brand-text mx-3">Mi Admin</div>
            </a>
            <hr class="sidebar-divider my-0">
            <li class="nav-item">
                <a class="nav-link" href="index.php">
                    <i class="fas fa-fw fa-tachometer-alt"></i>
                    <span>Dashboard</span></a>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="manage_macs.php">
                    <i class="fas fa-fw fa-table"></i>
                    <span>Gestionar MACs</span></a>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="register_mac.php">
                    <i class="fas fa-fw fa-address-book"></i>
                    <span>Registrar MAC</span></a>
            </li>
            <li class="nav-item">
                <a class="nav-link" href="register_site.php">
                    <i class="fas fa-fw fa-folder"></i>
                    <span>Registrar Sitios</span></a>
            </li>
            <hr class="sidebar-divider d-none d-md-block">
            <div class="text-center d-none d-md-inline">
                <button class="rounded-circle border-0" id="sidebarToggle"></button>
            </div>
        </ul>
        <!-- End of Sidebar -->

        <!-- Content Wrapper -->
        <div id="content-wrapper" class="d-flex flex-column">

            <!-- Main Content -->
            <div id="content">

                <!-- Topbar -->
                <nav class="navbar navbar-expand navbar-light bg-white topbar mb-4 static-top shadow">
                    <button id="sidebarToggleTop" class="btn btn-link d-md-none rounded-circle mr-3">
                        <i class="fa fa-bars"></i>
                    </button>
                    <ul class="navbar-nav ml-auto">
                        <li class="nav-item dropdown no-arrow">
                            <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                <span class="mr-2 d-none d-lg-inline text-gray-600 small"><?php echo $_SESSION['user_name']; ?></span>
                                <img class="img-profile rounded-circle" src="img/undraw_profile.svg">
                            </a>
                            <div class="dropdown-menu dropdown-menu-right shadow animated--grow-in" aria-labelledby="userDropdown">
                                <a class="dropdown-item" href="#">
                                    <i class="fas fa-user fa-sm fa-fw mr-2 text-gray-400"></i>
                                    Perfil
                                </a>
                                <div class="dropdown-divider"></div>
                                <a class="dropdown-item" href="logout.php">
                                    <i class="fas fa-sign-out-alt fa-sm fa-fw mr-2 text-gray-400"></i>
                                    Cerrar Sesión
                                </a>
                            </div>
                        </li>
                    </ul>
                </nav>
                <!-- End of Topbar -->

                <!-- Begin Page Content -->
                <div class="container-fluid">
                    <h2 class="h3 mb-4 text-gray-800">Registrar Sitio y Paquetes</h2>

                    <!-- Formulario para registrar un nuevo sitio -->
                    <form method="POST" action="register_site.php" class="mb-4">
                        <div class="card shadow mb-4">
                            <div class="card-header py-3">
                                <h6 class="m-0 font-weight-bold text-primary">Registrar Nuevo Sitio</h6>
                            </div>
                            <div class="card-body">
                                <label for="new_site_name">Nombre del Sitio:</label>
                                <input type="text" name="new_site_name" class="form-control" required>
                            </div>
                            <div class="card-footer">
                                <input type="submit" name="save_site" value="Guardar Sitio" class="btn btn-primary">
                            </div>
                        </div>
                    </form>

                    <!-- Formulario para registrar un nuevo paquete -->
                    <form id="packageForm" method="POST" action="register_site.php" enctype="multipart/form-data" class="mb-4">
                        <div class="card shadow mb-4">
                            <div class="card-header py-3">
                                <h6 class="m-0 font-weight-bold text-primary">Registrar Nuevo Paquete</h6>
                            </div>
                            <div class="card-body">
                                <label for="site_id">Selecciona el Sitio:</label>
                                <select name="site_id" class="form-control" required>
                                    <?php while ($site = $sites_result->fetch_assoc()) { ?>
                                        <option value="<?php echo $site['id']; ?>"><?php echo $site['site_name']; ?></option>
                                    <?php } ?>
                                </select>
                                <br>
                                <label for="new_package_name">Nombre del Paquete:</label>
                                <input type="text" name="new_package_name" class="form-control" required>
                                <br>
                                <label for="m3u8_file">Subir Archivo M3U o M3U8:</label>
                                <input type="file" name="m3u8_file" class="form-control" accept=".m3u,.m3u8" required>
                            </div>
                            <div class="card-footer">
                                <input type="submit" name="save_package" value="Guardar Paquete" class="btn btn-info">
                            </div>
                        </div>
                    </form>

                    <h3>Sitios Registrados</h3>
                    <form id="deleteSiteForm" method="POST" action="register_site.php">
                        <div class="card shadow mb-4">
                            <div class="card-header py-3">
                                <h6 class="m-0 font-weight-bold text-primary">Listado de Sitios</h6>
                            </div>
                            <div class="card-body">
                                <table class="table table-bordered">
                                    <thead>
                                        <tr>
                                            <th>Nombre del Sitio</th>
                                            <th>Acción</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        $sites_result->data_seek(0); // Reiniciar el resultado para reusar la consulta
                                        while ($site = $sites_result->fetch_assoc()) { ?>
                                            <tr>
                                                <td><?php echo $site['site_name']; ?></td>
                                                <td>
                                                    <button type="button" onclick="confirmDeleteSite(<?php echo $site['id']; ?>)" class="btn btn-danger">Eliminar</button>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </form>

                    <h3>Paquetes Registrados por Sitio</h3>
                    <form id="deletePackageForm" method="POST" action="register_site.php">
                        <div class="card shadow mb-4">
                            <div class="card-header py-3">
                                <h6 class="m-0 font-weight-bold text-primary">Listado de Paquetes</h6>
                            </div>
                            <div class="card-body">
                                <table class="table table-bordered">
                                    <thead>
                                        <tr>
                                            <th>Nombre del Paquete</th>
                                            <th>Sitio Asociado</th>
                                            <th>URL del XML</th>
                                            <th>Acción</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php while ($package = $packages_result->fetch_assoc()) { ?>
                                            <tr>
                                                <td><?php echo $package['package_name']; ?></td>
                                                <td>
                                                    <?php
                                                    $site_sql = "SELECT site_name FROM sites WHERE id = ?";
                                                    $site_stmt = $conn->prepare($site_sql);
                                                    $site_stmt->bind_param("i", $package['site_id']);
                                                    $site_stmt->execute();
                                                    $site_stmt->bind_result($site_name);
                                                    $site_stmt->fetch();
                                                    echo $site_name;
                                                    $site_stmt->close();
                                                    ?>
                                                </td>
                                                <td><?php echo $package['xml_url']; ?></td>
                                                <td>
                                                    <button type="button" onclick="confirmDeletePackage(<?php echo $package['id']; ?>)" class="btn btn-danger">Eliminar</button>
                                                </td>
                                            </tr>
                                        <?php } ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </form>

                    <br>
                    <a href="index.php" class="btn btn-primary">Regresar al Panel Principal</a>
                </div>
                <!-- /.container-fluid -->

            </div>
            <!-- End of Main Content -->

            <!-- Footer -->
            <footer class="sticky-footer bg-white">
                <div class="container my-auto">
                    <div class="copyright text-center my-auto">
                        <span>Copyright &copy; SISTEMAS TECNICOS E INGENIERIA 2024</span>
                    </div>
                </div>
            </footer>
            <!-- End of Footer -->

        </div>
        <!-- End of Content Wrapper -->

    </div>
    <!-- End of Page Wrapper -->

    <!-- JavaScript -->
    <script src="vendor/jquery/jquery.min.js"></script>
    <script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="vendor/jquery-easing/jquery.easing.min.js"></script>
    <script src="js/sb-admin-2.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

    <script>
        function confirmDeleteSite(siteId) {
            Swal.fire({
                title: '¿Estás seguro?',
                text: "¡No podrás revertir esto!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Sí, eliminar',
                cancelButtonText: 'Cancelar'
            }).then((result) => {
                if (result.isConfirmed) {
                    const form = document.getElementById('deleteSiteForm');
                    form.innerHTML += <input type="hidden" name="delete_site_id" value="${siteId}">;
                    form.submit();
                }
            })
        }

        function confirmDeletePackage(packageId) {
            Swal.fire({
                title: '¿Estás seguro?',
                text: "¡No podrás revertir esto!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Sí, eliminar',
                cancelButtonText: 'Cancelar'
            }).then((result) => {
                if (result.isConfirmed) {
                    const form = document.getElementById('deletePackageForm');
                    form.innerHTML += <input type="hidden" name="delete_package_id" value="${packageId}">;
                    form.submit();
                }
            })
        }

        document.getElementById('packageForm').addEventListener('submit', function(event) {
            event.preventDefault(); // Prevenir la acción de envío por defecto

            Swal.fire({
                title: 'Subiendo archivo...',
                text: 'Por favor espera mientras procesamos tu solicitud.',
                allowOutsideClick: false,
                didOpen: () => {
                    Swal.showLoading()
                }
            });

            // Crear objeto FormData y añadir los datos del formulario
            var formData = new FormData(this);

            // Enviar los datos usando AJAX
            fetch('register_site.php', {
                method: 'POST',
                body: formData
            })
            .then(response => response.text()) // Cambiar a text() para manejar las respuestas del servidor adecuadamente
            .then(data => {
                Swal.close(); // Cerrar la barra de carga

                if (data.includes("Éxito")) {
                    Swal.fire('Éxito', data, 'success').then(() => {
                        location.reload(); // Recargar la página
                    });
                } else {
                    Swal.fire('Error', data, 'error');
                }
            })
            .catch(error => {
                Swal.close();
                Swal.fire('Error', 'Hubo un problema con la subida del archivo.', 'error');
            });
        });
    </script>
</body>
</html>

<?php
$stmt->close();
$stmt_packages->close();
$conn->close();
?>