<?php
include 'db.php';
session_start();

// Verificar si el usuario tiene acceso
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: login.php");
    exit;
}

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $username = $_POST['username'];
    $password = password_hash($_POST['password'], PASSWORD_BCRYPT);
    $company_name = $_POST['company_name'];
    $country = $_POST['country'];
    $email = $_POST['email'];
    $contact_number = $_POST['contact_number'];
    $mac_limit = $_POST['mac_limit'];

    $sql = "INSERT INTO users (username, password, company_name, country, email, contact_number, mac_limit) VALUES (?, ?, ?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ssssssi", $username, $password, $company_name, $country, $email, $contact_number, $mac_limit);

    if ($stmt->execute()) {
        echo "<script>
            document.addEventListener('DOMContentLoaded', function() {
                Swal.fire({
                    title: 'Éxito',
                    text: 'Usuario registrado exitosamente.',
                    icon: 'success',
                    confirmButtonText: 'Aceptar'
                }).then(function() {
                    window.location = 'register_user.php';
                });
            });
        </script>";

        $user_folder = "uploads/" . preg_replace('/[^a-zA-Z0-9-]/', '', strtolower($company_name));
        if (!file_exists($user_folder)) {
            mkdir($user_folder, 0777, true);
        }
    } else {
        echo "<script>
            document.addEventListener('DOMContentLoaded', function() {
                Swal.fire({
                    title: 'Error',
                    text: 'Error al registrar el usuario: " . $stmt->error . "',
                    icon: 'error',
                    confirmButtonText: 'Aceptar'
                });
            });
        </script>";
    }

    $stmt->close();
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="es">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Registrar Usuario</title>
    <!-- Custom fonts and styles for this template -->
    <link href="vendor/fontawesome-free/css/all.min.css" rel="stylesheet" type="text/css">
    <link href="css/sb-admin-2.min.css" rel="stylesheet">
    <!-- SweetAlert2 -->
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
</head>

<body id="page-top">

<!-- Page Wrapper -->
<div id="wrapper">

    <!-- Sidebar -->
    <ul class="navbar-nav bg-gradient-primary sidebar sidebar-dark accordion" id="accordionSidebar">
        <!-- Sidebar - Brand -->
        <a class="sidebar-brand d-flex align-items-center justify-content-center" href="admin_dashboard.php">
            <div class="sidebar-brand-icon">
                <i class="fas fa-user-shield"></i>
            </div>
            <div class="sidebar-brand-text mx-3">Mi Admin</div>
        </a>

        <!-- Divider -->
        <hr class="sidebar-divider my-0">

        <!-- Nav Item - Dashboard -->
        <li class="nav-item">
            <a class="nav-link" href="admin_dashboard.php">
                <i class="fas fa-fw fa-tachometer-alt"></i>
                <span>Dashboard</span></a>
        </li>

        <!-- Divider -->
        <hr class="sidebar-divider">

        <!-- Heading -->
        <div class="sidebar-heading">
            Gestión
        </div>

        <!-- Nav Item - Register User -->
        <li class="nav-item">
            <a class="nav-link" href="register_user.php">
                <i class="fas fa-fw fa-user-plus"></i>
                <span>Registrar Usuario</span></a>
        </li>

        <!-- Nav Item - Manage Users -->
        <li class="nav-item">
            <a class="nav-link" href="manage_users.php">
                <i class="fas fa-fw fa-users"></i>
                <span>Gestionar Usuarios</span></a>
        </li>

        <!-- Divider -->
        <hr class="sidebar-divider d-none d-md-block">

        <!-- Sidebar Toggler (Sidebar) -->
        <div class="text-center d-none d-md-inline">
            <button class="rounded-circle border-0" id="sidebarToggle"></button>
        </div>

    </ul>
    <!-- End of Sidebar -->

    <!-- Content Wrapper -->
    <div id="content-wrapper" class="d-flex flex-column">

        <!-- Main Content -->
        <div id="content">

            <!-- Topbar -->
            <nav class="navbar navbar-expand navbar-light bg-white topbar mb-4 static-top shadow">

                <!-- Sidebar Toggle (Topbar) -->
                <button id="sidebarToggleTop" class="btn btn-link d-md-none rounded-circle mr-3">
                    <i class="fa fa-bars"></i>
                </button>

                <!-- Topbar Navbar -->
                <ul class="navbar-nav ml-auto">
                    <li class="nav-item dropdown no-arrow">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                            <span class="mr-2 d-none d-lg-inline text-gray-600 small"><?php echo $_SESSION['user_name']; ?></span>
                            <img class="img-profile rounded-circle" src="img/undraw_profile.svg">
                        </a>
                        <div class="dropdown-menu dropdown-menu-right shadow animated--grow-in" aria-labelledby="userDropdown">
                            <a class="dropdown-item" href="#">
                                <i class="fas fa-user fa-sm fa-fw mr-2 text-gray-400"></i>
                                Perfil
                            </a>
                            <div class="dropdown-divider"></div>
                            <a class="dropdown-item" href="logout.php">
                                <i class="fas fa-sign-out-alt fa-sm fa-fw mr-2 text-gray-400"></i>
                                Cerrar Sesión
                            </a>
                        </div>
                    </li>
                </ul>
            </nav>
            <!-- End of Topbar -->

            <!-- Begin Page Content -->
            <div class="container-fluid">

                <!-- Page Heading -->
                <h1 class="h3 mb-4 text-gray-800">Registrar Nuevo Usuario</h1>

                <!-- Formulario de Registro -->
                <div class="row justify-content-center">
                    <div class="col-lg-8">
                        <div class="card shadow mb-4">
                            <div class="card-header py-3">
                                <h6 class="m-0 font-weight-bold text-primary">Formulario de Registro</h6>
                            </div>
                            <div class="card-body">
                                <form class="user" method="POST" action="register_user.php" autocomplete="off">
                                    <div class="form-group">
                                        <input type="text" class="form-control form-control-user" name="username" placeholder="Nombre de Usuario" required autocomplete="new-password">
                                    </div>
                                    <div class="form-group">
                                        <input type="password" class="form-control form-control-user" name="password" placeholder="Contraseña" required autocomplete="new-password">
                                    </div>
                                    <div class="form-group">
                                        <input type="text" class="form-control form-control-user" name="company_name" placeholder="Nombre de la Empresa" required>
                                    </div>
                                    <div class="form-group">
                                        <select name="country" class="form-control">
                                            <option value="">Seleccione un país</option>
                                            <option value="Belize">Belice</option>
                                            <option value="Costa Rica">Costa Rica</option>
                                            <option value="El Salvador">El Salvador</option>
                                            <option value="Guatemala">Guatemala</option>
                                            <option value="Honduras">Honduras</option>
                                            <option value="Nicaragua">Nicaragua</option>
                                            <option value="Panama">Panamá</option>
                                            <option value="United States">Estados Unidos</option>
                                            <option value="Bahamas">Bahamas</option>
                                            <option value="Cuba">Cuba</option>
                                            <option value="Dominican Republic">República Dominicana</option>
                                            <option value="Haiti">Haití</option>
                                            <option value="Jamaica">Jamaica</option>
                                            <option value="Puerto Rico">Puerto Rico</option>
                                            <option value="Trinidad and Tobago">Trinidad y Tobago</option>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <input type="email" class="form-control form-control-user" name="email" placeholder="Correo Electrónico" required>
                                    </div>
                                    <div class="form-group">
                                        <input type="text" class="form-control form-control-user" name="contact_number" placeholder="Número de Contacto" required>
                                    </div>
                                    <div class="form-group">
                                        <label for="mac_limit" class="text-gray-900">Límite de MACs</label>
                                        <input type="number" class="form-control form-control-user" name="mac_limit" value="0" min="0" required>
                                    </div>
                                    <input type="submit" class="btn btn-primary btn-user btn-block" value="Registrar Usuario">
                                </form>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
            <!-- /.container-fluid -->

        </div>
        <!-- End of Main Content -->

        <!-- Footer -->
        <footer class="sticky-footer bg-white">
            <div class="container my-auto">
                <div class="copyright text-center my-auto">
                    <span>Copyright &copy; SISTEMAS TECNICOS E INGENIERIA 2024</span>
                </div>
            </div>
        </footer>
        <!-- End of Footer -->

    </div>
    <!-- End of Content Wrapper -->

</div>
<!-- End of Page Wrapper -->

<!-- Bootstrap core JavaScript-->
<script src="vendor/jquery/jquery.min.js"></script>
<script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>

<!-- Core plugin JavaScript-->
<script src="vendor/jquery-easing/jquery.easing.min.js"></script>

<!-- Custom scripts for all pages-->
<script src="js/sb-admin-2.min.js"></script>

</body>

</html>